import csv
import xlrd
import cpa

def read_descriptions():
    descriptions = {}
    book = xlrd.open_workbook("../inputs/CDRP-compound-annotations.xls")
    sh = book.sheet_by_index(0)
    header = sh.row(0)
    assert header[2].value == 'VERB'
    assert header[3].value == 'ANNO_TERM'
    assert header[5].value == 'ANNO_DB_ID'
    for i in range(1, sh.nrows):
        row = sh.row(i)
        verb = row[2].value
        anno_term = row[3].value
        anno_db_id = row[5].value
        if verb:
            descriptions[anno_db_id] = '%s %s' % (verb, anno_term)
        else:
            descriptions[anno_db_id] = anno_term
    return descriptions

def read_annotations(broad_ids):
    anno_map = {}
    book = xlrd.open_workbook("../inputs/CDRP-compound-annotations.xls")
    sh = book.sheet_by_index(0)
    header = sh.row(0)
    assert header[0].value == 'BROAD_ID'
    assert header[5].value == 'ANNO_DB_ID'
    for i in range(1, sh.nrows):
        row = sh.row(i)
        broad_id = row[0].value[:13]
        anno_db_id = row[5].value
        anno_map.setdefault(broad_id, []).append(anno_db_id)

    return dict((k, v) for k, v in anno_map.items() 
                if broad_ids is None or k in broad_ids)

def read_slim():
    slim_map = {}

    reader = csv.reader(open('../inputs/GOslimMap.txt', 'rU'), delimiter='\t')
    header = reader.next()
    assert header[0] == 'GOID'
    assert header[1] == 'GOslimID'
    for row in reader:
        slim_map.setdefault(row[0], []).append(row[1])

    book = xlrd.open_workbook("../inputs/SlimmingForCDRP.xls")
    sh = book.sheet_by_index(0)
    header = sh.row(0)
    assert header[0].value == 'ANNO_DB_ID'
    assert header[1].value == 'SlimMeSHID'
    for i in range(1, sh.nrows):
        row = sh.row(i)
        anno_db_id = row[0].value
        for slimmed in row[1].value.split(';'):
            slim_map.setdefault(anno_db_id, []).append('MeSH:' + slimmed)

    sh = book.sheet_by_index(1)
    header = sh.row(0)
    assert header[0].value == 'ANNO_DB_ID'
    assert header[2].value == 'SlimTo'
    for i in range(1, sh.nrows):
        row = sh.row(i)
        anno_db_id = row[0].value
        slim_to = row[2].value
        if slim_to == 'self':
            slim_to = anno_db_id
        else:
            slim_to = 'UseClass:' + str(int(slim_to))
        slim_map.setdefault(anno_db_id, []).append(slim_to)

    sh = book.sheet_by_index(2)
    header = sh.row(0)
    assert header[0].value == 'ANNO_DB_ID'
    assert header[1].value == 'GOMF'
    for i in range(1, sh.nrows):
        row = sh.row(i)
        anno_db_id = row[0].value
        gomf = row[1].value
        if gomf:
            slim_map.setdefault(anno_db_id, []).append(gomf)

    return slim_map

def slim_annotations(annotations):
    slim_map = read_slim()
    found = set()
    missing = set()
    for k, values in annotations.items():
        for v in values:
            if v in slim_map:
                found.add(v)
            else:
                missing.add(v)
    print len(missing), 'of', (len(missing) + len(found)), 'terms are not slimmed:'
    counts = {}
    for term in missing:
        term_type = term.split(':')[0]
        counts[term_type] = counts.get(term_type, 0) + 1
    for term_type, count in counts.items():
        print '   %3d %s' % (count, term_type)
    return dict((k, [s for v in values
                     for s in (slim_map[v] if v in slim_map else [v])])
                for k, values in annotations.items())


