import numpy as np
import cpa
from cpa.profiling.profiles import Profiles
from cpa.profiling.normalization import DummyNormalization
from util import cached

@cached("../results/HEAD/mock_image_keys_per_plate.pickle")
def get_mock_image_keys_per_plate():
    dbres = cpa.db.execute("SELECT DISTINCT ImageNumber, Image_Metadata_PlateID FROM %s WHERE Image_Metadata_ASSAY_WELL_ROLE = 'mock'" % (cpa.properties.image_table))
    plate_images = {}
    for image_number, plate in dbres:
        plate = int(plate)
        image_key = (int(image_number),)
        plate_images.setdefault(plate, []).append(image_key)
    return plate_images

@cached("../results/HEAD/standardization_parameters.pickle")
def get_standardization_parameters(cache):
    plate_images = get_mock_image_keys_per_plate()
    params = {}
    for plate, images in plate_images.items():
        data = cache.load(images, normalization=DummyNormalization)[0]
        means = data.mean(0)
        stds = data.std(0)
        params[plate] = (means, stds)
    return params

@cached("../results/HEAD/compound_image_keys_per_broad_id.pickle")
def get_compound_image_keys_per_broad_id():
    """Returns dict broad_id -> plate -> list of image_keys."""
    dbres = cpa.db.execute("SELECT DISTINCT ImageNumber, Image_Metadata_PlateID, Image_Metadata_BROAD_ID FROM %s WHERE Image_Metadata_ASSAY_WELL_ROLE = 'compound'" % (cpa.properties.image_table))
    d = {}
    for image_number, plate, broad_id in dbres:
        image_key = (int(image_number),)
        plate = int(plate)
        broad_id = broad_id[:13]
        d.setdefault(broad_id, {}).setdefault(plate, []).append(image_key)
    return d

@cached("../results/HEAD/broad_ids_in_order.pickle")
def get_broad_ids_in_order():
    with open('../results/HEAD/mean.broad_id.95.filtered.leaforder.txt') as f:
        leaforder = [int(s) - 1 for s in f.readlines()]
    profiles = Profiles.load('../results/HEAD/mean.broad_id.95.filtered.profiles.txt')
    profiles.data = profiles.data[np.array(leaforder), :]
    profiles._keys = [profiles._keys[i] for i in leaforder]
    active_annotated_broad_ids = [b[:13] for (b,) in profiles.keys() if b != 'DMSO']
    return active_annotated_broad_ids

@cached("../results/HEAD/mock_images_per_wellpos.pickle")
def get_mock_images_per_wellpos():
    dbres = cpa.db.execute("SELECT DISTINCT ImageNumber, Image_Metadata_PlateID, Image_Metadata_CPD_WELL_POSITION FROM %s WHERE Image_Metadata_ASSAY_WELL_ROLE = 'mock'" % (cpa.properties.image_table))
    d = {}
    for image_number, plate, wellpos in dbres:
        image_key = (int(image_number),)
        plate = int(plate)
        d.setdefault(wellpos, {}).setdefault(plate, []).append(image_key)
    return d


