#!/usr/bin/env python

import numpy as np
from docx import *
import cpa.util
from common import *

load_properties()

input_filename = '../results/HEAD/mean.broad_id.95.filtered.hits'
smF, profiles, all_terms, \
    smC, smS, cluster_sizes, hits = cpa.util.unpickle(input_filename)
broad_ids = [k[0][:13] for k in profiles.keys()]

brd_to_name = {}
for cpd, brd in cpa.db.execute("""select distinct Image_Metadata_SOURCE_COMPOUND_NAME, Image_Metadata_BROAD_ID from Pilot_PartI_Per_Image"""):
    brd_to_name[brd[:13]] = cpd

rows = [['Rank', 'Score', '#compounds', 'Term occ.', 'Has term', 'Compound name', 'Broad ID']]
topn = 50
argsorted = np.argsort(hits, None)
for rank0, index in enumerate(argsorted[:topn]):
    cluster_index, term_index = np.unravel_index(index, hits.shape)
    pvalue = hits[cluster_index, term_index]
    compound_mask = smS[:, cluster_index]
    cluster_size = cluster_sizes[cluster_index]
    term_count = smF[compound_mask, term_index].sum()
    term_total = smF[:, term_index].sum()
    cluster_id = cluster_index + 1
    term_id = term_index + 1
    term = all_terms[term_index]
    first = True
    for cix, member in enumerate(compound_mask):
        if not member:
            continue
        brd = broad_ids[cix]
        compound_name = brd_to_name.get(brd, brd)
        has_term = smF[cix, term_index]

        if first:
            row = ['%d' % (rank0 + 1), '%.4f' % pvalue, '%d' % cluster_size, 
                   '%d of %d' % (term_count, term_total)]
            first = False
        else:
            row = ['', '', '', '']
        row.extend([['', 'Yes'][has_term], compound_name, brd])
        rows.append(row)

#
# Make the Word document
#

relationships = relationshiplist()
document = newdocument()
docbody = document.xpath('/w:document/w:body', namespaces=nsprefixes)[0]

docbody.append(table(rows))

coreprops = coreproperties(title='',subject='',creator='',keywords=[])
appprops = appproperties()
contenttypes = contenttypes()
websettings = websettings()
wordrelationships = wordrelationships(relationships)

# Save our document
savedocx(document,coreprops,appprops,contenttypes,websettings,wordrelationships,'../results/HEAD/supp_table_clusters.docx')
