#!/usr/bin/env python
# -*- Encoding: utf-8 -*-
#
# Needs to be run from the "structures" directory because of the broken
# way in which python-docx copies the pictures that are to be inserted
# into the document.

import sys
import os.path
try:
    from PIL import Image
except ImportError:
    import Image
import cpa
from annotations import read_annotations
import filter_profiles
from cpa.profiling.profiles import Profiles
from docx import *

cpa.properties.LoadFile('../code/CDRP_Current.properties')

def export_compounds(broad_ids, filename):
    global relationships

    dbresult = cpa.db.execute("""
    SELECT DISTINCT Image_Metadata_SOURCE_COMPOUND_NAME, 
    Image_Metadata_CPD_MMOL_CONC, Image_Metadata_SOURCE_NAME, 
    Image_Metadata_BROAD_ID
    FROM %s ORDER BY Image_Metadata_SOURCE_COMPOUND_NAME, 
    Image_Metadata_CPD_MMOL_CONC""" % (cpa.properties.image_table,))

    # Default set of relationshipships - these are the minimum components of a document
    relationships = relationshiplist()

    # Make a new document tree - this is the main part of a Word document
    document = newdocument()

    # This xpath location is where most interesting content lives 
    docbody = document.xpath('/w:document/w:body', namespaces=nsprefixes)[0]

    def get_structure(broad_id):
        global relationships
        fn = '%s.png' % broad_id
        if os.path.exists(fn):
            print fn
            w, h = Image.open(fn).size[0:2]
            relationships, picpara = picture(relationships, fn, broad_id, pixelwidth=w//5, pixelheight=h//5)
            return picpara
        else:
            print 'File not found:', fn
            return ''

    docbody.append(table(
            [['Compound name', u'Concentration [µM]', 'Source', 'Broad ID', 'Structure']] +
            [[name.upper(), '%.2f' % float(conc) if conc else '', source, broad_id[:13], get_structure(broad_id)]
                          for (name, conc, source, broad_id) in dbresult
                          if broad_ids is None or broad_id[:13] in broad_ids]))

    # Save our document
    savedocx(document, coreproperties(title='', subject='', 
                                      creator='', keywords=[]), 
             appproperties(), contenttypes(), websettings(), 
             wordrelationships(relationships), filename)

export_compounds(None, '../results/HEAD/supp_table_compounds.docx')
annotated_broad_ids = read_annotations(None).keys()
export_compounds(annotated_broad_ids, '../results/HEAD/supp_table_compounds_annotated.docx')

profiles = Profiles.load('../results/HEAD/mean.broad_id.95.filtered.profiles.txt')
active_annotated_broad_ids = [b[:13] for (b,) in profiles.keys()]
export_compounds(active_annotated_broad_ids, '../results/HEAD/supp_table_compounds_active_annotated.docx')


