#!/usr/bin/env python
#
# Use permutation testing to rank clusters by term enrichment.

import sys
import numpy as np
import progressbar
import cpa
import cpa.util

input_stem, output_filename = sys.argv[1:]
smF, profiles, all_terms = cpa.util.unpickle(input_stem + '.profiles.pickle')
smC = np.genfromtxt(input_stem + '.smC.txt') > 0

ncompounds = smC.shape[0]
nclusters = ncompounds

keepC = (smC.sum(0) > 1) & (smC.sum(0) <= ncompounds)
keepC[-1] = True
smS = smC[:, keepC]
cluster_sizes = smS.sum(0)
# XXX: Not removing rare terms

nterms = smF.shape[1]
def score_by_permutation_test(sample_size):
    contingency = np.dot(np.array(smS, dtype=int).T, 
                         np.array(smF, dtype=int))
    random_observations = np.zeros((sample_size, nterms))
    hits = np.zeros(contingency.shape)
    progress = progressbar.ProgressBar(widgets=[progressbar.Percentage(), ' ', 
                                                progressbar.Bar(), ' ', 
                                                progressbar.ETA()])
    for cluster in progress(range(nclusters)):
        for i in range(sample_size):
            compound_ids = np.random.randint(0, ncompounds, cluster_sizes[cluster])
            random_observations[i, :] = smF[compound_ids, :].sum(0)
        hits[cluster, :] = (random_observations >= contingency[cluster, :]).sum(0)
    return hits / sample_size

#sample_size = len(sys.argv) == 2 and int(sys.argv[1]) or 100000
sample_size = 10000
hits = score_by_permutation_test(sample_size)

cpa.util.pickle(output_filename, smF, profiles, all_terms,
                smC, smS, cluster_sizes, hits)
