function outC = uclid(inC)
    % outC = uclid(inC)
    % create unique cluster IDs from matrix output of cluster.m

    assert(numel(size(inC))==2,'Input inC must be a 2D matrix.');
    assert(size(inC,1)>1,'Input inC must have at least 2 rows.');
    assert(size(inC,1)>=size(inC,2),'Input inC may not have more columns than rows.');
    assert(isequal(inC,fix(inC)),'Input inC must contain integer indices.');
    assert(max(inC(:))<=size(inC,1),'Input inC may not have higher indices than row numbers.');
    assert(min(min(inC))==1&&max(min(inC)),'Each column of inC must start with index 1.');

    maxC = max(inC); % make vector of maxima across inC
    nC = size(inC,2); % count columns;
    % make sure clusters start with ids [1:maxclust]
    for id=1:nC
        if id<nC
            assert(maxC(id)<maxC(id+1),'Max values in columns of inC must monotonically increase.');
        end
        thisC = sort(unique(inC(:,id)));
        thisX = max(inC(:,id));
        assert(isequal(thisC,(1:thisX)'),'Each column of inC must contain continuous indices.');
    end

    % start with cluster ID ranges that are different for each cluster level
    for id=2:nC 
        maxC = max(inC(:,id-1));
        thisC = inC(:,id);
        thisC = thisC+maxC;
        inC(:,id) = thisC;
    end
    
    % make a matrix to contain all compositions
    B = true(max(inC(:)),size(inC,1)); 
    [I J] = ind2sub(size(inC),1:numel(inC));
    I = I';
    V = inC(:);
    
    % fill out the composition matrix (false=included)
    for id=1:numel(V); 
        B(V(id),I(id)) = false;
    end
    [b m n] = unique(B,'rows','last');
    
    % reassign new IDs to each unique composition
    outC = zeros(size(inC));
    inC = inC(:);
    tempC = zeros(size(inC));
    for id=1:numel(tempC)
        tempC(id) = n(inC(id));
    end
    [z1 z2] = unique(tempC,'first');
    [z3 z4] = sort(z2);
    
    % renumber unique composition IDs
    putC = zeros(size(tempC));
    for id=1:numel(putC)
        putC(id) = z1(tempC(id)==z4);
    end
    
    outC(:) = putC;

end
